{% extends "account/base_entrance.html" %}
{% load i18n %}
{% block head_title %}
    {% trans "Change Password" %}
{% endblock head_title %}

{% block content %}
<div class="h-screen bg-gray-50 flex flex-col justify-center items-center">

    <div class="bg-white border border-gray-300 w-80 md:w-96 py-8 px-4 flex items-center flex-col mb-3">
   <h1 class="text-2xl font-semibold mb-4">
        {% trans "Change Password" %}
    </h1>

    <p class="text-sm text-center text-gray-700">
        {% trans "Your password is now changed." %}
    </p>
    </div>
    
</div>
    
{% endblock content %}
