{% extends "account/base_entrance.html" %}
{% load i18n %}
{% load allauth %}

{% block head_title %}
    {% trans "Verify Your Email Address" %}
{% endblock head_title %}

{% block content %}
<div class="max-w-md mx-auto mt-10 bg-white shadow-lg rounded-lg p-6">
    <h1 class="text-2xl font-semibold text-gray-800 mb-4">
        {% trans "Verify Your Email Address" %}
    </h1>
    <p class="text-gray-600 text-sm">
        {% blocktrans %}
        We've sent a verification link to your email address.
        Please click the link in that email to complete your sign-up.
        If you can't find the email, check your spam folder.
        {% endblocktrans %}
    </p>
    <div class="mt-6">
        <p class="text-sm text-gray-500">
            {% blocktrans %}
            {% endblocktrans %}
        </p>
    </div>
</div>
{% endblock content %}
