{% extends "account/base_entrance.html" %}
{% load i18n %}
{% block head_title %}
    {% trans "Password Reset" %}
{% endblock head_title %}

{% block content %}
<div class="h-screen bg-gray-50 flex flex-col justify-center items-center">

    <div class="bg-white border border-gray-300 w-80 md:w-96 py-8 px-4 flex items-center flex-col mb-3">
        <h1 class="text-xl font-semibold mb-4">
            {% trans "Password Reset" %}
        </h1>

        {% if user.is_authenticated %}
            <p class="mb-2 text-sm text-gray-600">
                {% include "account/snippets/already_logged_in.html" %}
            </p>
        {% endif %}

        <p class="text-sm text-center text-gray-700 mt-3">
            {% blocktrans %}We have sent you an email. If you have not received it, please check your spam folder. Otherwise, contact us if you do not receive it in a few minutes.{% endblocktrans %}
        </p>
    </div>
    
</div>
    
{% endblock content %}
